@@ -17,33 +17,45 @@ Input = str  # The input to an NLP mode
 Outputs = List[str]  # The different acceptable outputs of the NLP, string label or number, but in string format
 
 Performance = float  # usually between zero & one (one is better)
+
+# Callable that returns the performance of a model given an input and expected outputs.
 ModelEvaluator = Callable[[Input, Outputs], Performance]
 
 Category = str  # The different kinds of data produced by augmenters.
 
 
 class Augmenter(metaclass=abc.ABCMeta):
+    """Objects that can transform an input to another input from a target category.
+
+    Also include objects which can do paraphrase."""
+
     @abc.abstractproperty
     def categories(self) -> Tuple[Category, ...]:
-        """Categories the augmenter can output.
-
-        Empty tuple if paraphrase."""
+        """Categories the augmenter can output."""
         ...
 
     @abc.abstractmethod
-    def transform(self, inp: Input, to: Category = "") -> Input:
+    def transform(self, inp: Input, to: Category) -> Input:
         """Transform the input to make it a member of the target category.
 
-        Returns the input unchanged if the input is already a member of the target category or if
-        the transformation is not applicable.
+        Return the input unchanged if the input is already a member of the target category or if
+        the transformation is not applicable."""
+        ...
 
-        The to argument doesn't need to be used for paraphrase."""
+
+class Paraphraser(Augmenter):
+    """Objects that can transform an input to another input with the same meaning."""
+
+    @abc.abstractmethod
+    def transform(self, inp: Input, to: Category = "") -> Input:
+        """Transform the input to make it another input with the same meaning.
+
+        Ignore the target category."""
         ...
 
     @property
-    def is_paraphrase(self) -> bool:
-        """Is this augmenter doing paraphrase."""
-        return len(self.categories) == 0
+    def categories(self) -> Tuple[Category, ...]:
+        return ()
 
 
 class Variation(NamedTuple):
